package com.logicbig.example;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import java.util.List;

public class ExampleMain2 {

    public static void main(String[] args) throws Exception {
        EntityManagerFactory emf =
                Persistence.createEntityManagerFactory("example-unit");
        try {
            persistEntities(emf);
            runNativeQueries(emf);
            loadEntities(emf);
        } finally {
            emf.close();
        }
    }

    private static void persistEntities(EntityManagerFactory emf) throws Exception {
        System.out.println("-- Persisting entities --");
        EntityManager em = emf.createEntityManager();

        Rectangle r = new Rectangle();
        r.setWidth(200);
        r.setHeight(100);
        r.setOrigin(10,10);
        System.out.println(r);

        Circle c = new Circle();
        c.setRadius(50);
        System.out.println(c);

        em.getTransaction().begin();
        em.persist(r);
        em.persist(c);
        em.getTransaction().commit();
        em.close();
    }

    private static void runNativeQueries(EntityManagerFactory emf) {
        System.out.println("-- Native queries --");
        EntityManager em = emf.createEntityManager();
        ExampleMain.nativeQuery(em, "Select * from RECTANGLE");
        ExampleMain.nativeQuery(em, "Select * from CIRCLE");
    }

    private static void loadEntities(EntityManagerFactory emf) {
        System.out.println("-- Loading and drawing shapes --");
        EntityManager em = emf.createEntityManager();
        System.out.println("Loading from Rectangle:");
        List<Shape> shapes = em.createQuery("Select t from Rectangle t")
                                   .getResultList();
        shapes.forEach(System.out::println);
        for (Shape shape : shapes) {
            shape.setOrigin(5, 10);
            shape.draw();
        }

        System.out.println("Loading from Circle:");
         shapes = em.createQuery("Select t from Circle t")
                                   .getResultList();
        shapes.forEach(System.out::println);
        for (Shape shape : shapes) {
            shape.setOrigin(10, 10);
            shape.draw();
        }

        em.close();
    }
}